@@ -9,6 +9,7 @@ import datetime
 import math
 import numpy as np
 import pytz
+from dateutil.parser import parse
 import pytplot
 from platform import system
 import copy
@@ -153,12 +154,35 @@ def set_tplot_options(option, value, old_tplot_opt_glob):
     elif option == 'ymargin':
         new_tplot_opt_glob['ymargin'] = value
 
+    elif option == 'style':
+        new_tplot_opt_glob['style'] = value
+
+    elif option == 'charsize':
+        new_tplot_opt_glob['charsize'] = value
+
+    elif option == 'xsize':
+        new_tplot_opt_glob['xsize'] = value
+
+    elif option == 'ysize':
+        new_tplot_opt_glob['ysize'] = value
+
     else:
         print("Unknown option supplied: " + str(option))
 
     return new_tplot_opt_glob
 
 
+def str_to_int_fuzzy(time_str):
+    """
+    Implementation of str_to_int (below) that uses dateutil and .timestamp()
+    to convert the date/time string to integer (number of seconds since Jan 1, 1970)
+
+    This function is slower than str_to_int, but more flexible
+    """
+    dt_object = parse(time_str)
+    return int(int(dt_object.replace(tzinfo=datetime.timezone.utc).timestamp()))
+
+
 def str_to_int(time_str):
     epoch_t = "1970-1-1 00:00:00"
     if 'T' in time_str:
@@ -657,6 +681,11 @@ def get_y_range(dataset):
         y_min = np.nan
         y_max = np.nan
 
+    # CDF files may have array of strings (e.g., RBSP EMFISIS)
+    if isinstance(y_min, str):
+        y_min = np.nan
+        y_max = np.nan
+        
     if y_min == y_max:
         # Show 10% and 10% below the straight line
         y_min = y_min - (.1 * np.abs(y_min))
